@@ -52,8 +52,12 @@ fn home_dir() -> String {
 }
 
 fn install_hook(hook_path: &Path, hook_name: &str) -> Result<(), GitMitInstallError> {
-    let binary_path = which::which(format!("mit-{}", hook_name)).unwrap();
-    let install_path = hook_path.join(hook_name);
+    #[cfg(target_os = "windows")]
+    let suffix = ".exe";
+    #[cfg(not(target_os = "windows"))]
+    let suffix = "";
+    let binary_path = which::which(format!("mit-{}{}", hook_name, suffix)).unwrap();
+    let install_path = hook_path.join(format!("{}{}", hook_name, suffix));
     let install_path_destination = install_path.read_link();
     if let Ok(existing_hook_path) = install_path_destination.and_then(|x| x.canonicalize()) {
         if existing_hook_path == install_path {
